# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2015-12-19 21:30
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('example', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Measurement',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('value', models.IntegerField()),
                ('timestamp', models.DateTimeField(auto_now_add=True)),
            ],
            options={
                'ordering': ('-timestamp',),
            },
        ),
        migrations.RemoveField(
            model_name='datapooling',
            name='measurement',
        ),
        migrations.AddField(
            model_name='measurement',
            name='datapooling',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='example.DataPooling'),
        ),
    ]
